##
##  prometheus.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_prometheus_base 2.54.1
%define       V_prometheus_snap 20240829

#   package information
Name:         prometheus
Summary:      Monitoring System And Time Series Database
URL:          http://prometheus.io/
Vendor:       Matt T. Proud, Julius Volz
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Networking
License:      Apache
Version:      %{V_prometheus_base}.%{V_prometheus_snap}
Release:      20240830

#   list of sources
Source0:      http://download.openpkg.org/components/versioned/prometheus/prometheus-%{V_prometheus_snap}.tar.xz
Source1:      rc.prometheus
Source2:      prometheus.conf

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, go, xxd
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Prometheus is an Open-Source service monitoring system and time
    series database. Prometheus implements a highly dimensional data
    model. Time series are identified by a metric name and a set of
    key-value pairs. A flexible query language allows slicing and dicing
    of collected time series data in order to generate ad-hoc graphs,
    tables, and alerts. Prometheus has multiple modes for visualizing
    data: a built-in expression browser, a GUI-based dashboard builder,
    and a console template language. Prometheus stores time series in
    memory and on local disk in an efficient custom format. Scaling is
    achieved by functional sharding and federation.

%track
    prog prometheus:release = {
        version   = %{V_prometheus_base}
        url       = https://github.com/prometheus/prometheus/releases
        regex     = (\d+\.\d+\.\d+)\.tar\.gz
    }
    prog prometheus:snapshot = {
        version   = %{V_prometheus_snap}
        url       = http://download.openpkg.org/components/versioned/prometheus/
        regex     = prometheus-(__VER__)\.tar\.xz
    }

%prep
    %setup -q -n prometheus

%build
    #   build program
    export GOPATH=`pwd`
    export HOME=`pwd`
    cd src/github.com/prometheus/prometheus
    %{l_make} %{l_mflags} build

%install
    #   create directory hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/prometheus \
        $RPM_BUILD_ROOT%{l_prefix}/var/prometheus/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/prometheus/run \
        $RPM_BUILD_ROOT%{l_prefix}/var/prometheus/data

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/github.com/prometheus/prometheus/prometheus \
        $RPM_BUILD_ROOT%{l_prefix}/sbin/prometheus
    %{l_shtool} install -c -s -m 755 \
        src/github.com/prometheus/prometheus/promtool \
        $RPM_BUILD_ROOT%{l_prefix}/bin/promtool

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE prometheus.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/prometheus/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.prometheus} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/prometheus/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/prometheus/*'

%files -f files

%clean

%post
    #   after upgrade, restart service
    [ $1 -eq 2 ] || exit 0
    eval `%{l_rc} prometheus status 2>/dev/null`
    [ ".$prometheus_active" = .yes ] && %{l_rc} prometheus restart
    exit 0

%preun
    #   before erase, stop service and remove log files
    [ $1 -eq 0 ] || exit 0
    %{l_rc} prometheus stop 2>/dev/null
    rm -rf $RPM_INSTALL_PREFIX/var/prometheus/log/*  >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/prometheus/run/*  >/dev/null 2>&1 || true
    rm -rf $RPM_INSTALL_PREFIX/var/prometheus/data/* >/dev/null 2>&1 || true
    exit 0

